Auto Play All Videos

# Text-to-Video Comparison

SmooSense provides a platform to evaluate and compare different text-to-video AI models. By presenting videos generated from the same prompt side-by-side, it allows for a direct visual assessment of each model's quality and performance.

This example shows how to analyze and compare video generation results from multiple models using the same prompts and reference images.

## Data Source

Data is excerpted from: Rapidata/image-to-video-human-preference-hailuo-02-marey

## Use SmooSense to compare videos

- Hover at a video to play.
- Click the switch to turn on/off auto-play for all videos.